# coding: utf-8

# flake8: noqa
"""
    Manticore Search Client

    Сlient for Manticore Search.   # noqa: E501

    The version of the OpenAPI document: 3.3.1
    Contact: info@manticoresearch.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from manticoresearch.model.aggregation import Aggregation
from manticoresearch.model.aggregation_sort_inner_value import AggregationSortInnerValue
from manticoresearch.model.aggregation_terms import AggregationTerms
from manticoresearch.model.attr_filter import AttrFilter
from manticoresearch.model.bool_filter import BoolFilter
from manticoresearch.model.bulk_response import BulkResponse
from manticoresearch.model.delete_document_request import DeleteDocumentRequest
from manticoresearch.model.delete_response import DeleteResponse
from manticoresearch.model.equals_filter import EqualsFilter
from manticoresearch.model.error_response import ErrorResponse
from manticoresearch.model.facet import Facet
from manticoresearch.model.filter_boolean import FilterBoolean
from manticoresearch.model.filter_number import FilterNumber
from manticoresearch.model.filter_string import FilterString
from manticoresearch.model.fulltext_filter import FulltextFilter
from manticoresearch.model.geo_distance_filter import GeoDistanceFilter
from manticoresearch.model.geo_distance_filter_location_anchor import GeoDistanceFilterLocationAnchor
from manticoresearch.model.highlight import Highlight
from manticoresearch.model.highlight_field import HighlightField
from manticoresearch.model.in_filter import InFilter
from manticoresearch.model.insert_document_request import InsertDocumentRequest
from manticoresearch.model.knn_query_by_doc_id import KnnQueryByDocId
from manticoresearch.model.knn_query_by_vector import KnnQueryByVector
from manticoresearch.model.match_filter import MatchFilter
from manticoresearch.model.match_op import MatchOp
from manticoresearch.model.match_op_filter import MatchOpFilter
from manticoresearch.model.match_phrase_filter import MatchPhraseFilter
from manticoresearch.model.not_filter_boolean import NotFilterBoolean
from manticoresearch.model.not_filter_number import NotFilterNumber
from manticoresearch.model.not_filter_string import NotFilterString
from manticoresearch.model.option import Option
from manticoresearch.model.percolate_request import PercolateRequest
from manticoresearch.model.percolate_request_query import PercolateRequestQuery
from manticoresearch.model.query_filter import QueryFilter
from manticoresearch.model.range_filter import RangeFilter
from manticoresearch.model.replace_document_request import ReplaceDocumentRequest
from manticoresearch.model.search_request import SearchRequest
from manticoresearch.model.search_request_knn import SearchRequestKnn
from manticoresearch.model.search_response import SearchResponse
from manticoresearch.model.search_response_hits import SearchResponseHits
from manticoresearch.model.sort_mva import SortMVA
from manticoresearch.model.sort_multiple import SortMultiple
from manticoresearch.model.sort_order import SortOrder
from manticoresearch.model.source_by_rules import SourceByRules
from manticoresearch.model.source_multiple import SourceMultiple
from manticoresearch.model.sql_response import SqlResponse
from manticoresearch.model.success_response import SuccessResponse
from manticoresearch.model.update_document_request import UpdateDocumentRequest
from manticoresearch.model.update_response import UpdateResponse



# coding: utf-8

# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
# 
# All rights reserved
#



from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six
from six.moves.urllib.parse import quote

from manticoresearch.api_client import ApiClient
from manticoresearch.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class SearchApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def percolate(self, index, percolate_request, **kwargs):  # noqa: E501
        """Perform reverse search on a percolate index  # noqa: E501

        Performs a percolate search.  This method must be used only on percolate indexes.  Expects two parameters: the index name and an object with array of documents to be tested. An example of the documents object:    ```   {     \"query\":     {       \"percolate\":       {         \"document\":         {           \"content\":\"sample content\"         }       }     }   }   ```  Responds with an object with matched stored queries:     ```   {     'timed_out':false,     'hits':     {       'total':2,       'max_score':1,       'hits':       [         {           '_index':'idx_pq_1',           '_type':'doc',           '_id':'2',           '_score':'1',           '_source':           {             'query':             {               'match':{'title':'some'}             }           }         },         {           '_index':'idx_pq_1',           '_type':'doc',           '_id':'5',           '_score':'1',           '_source':           {             'query':             {               'ql':'some | none'             }           }         }       ]     }   }   ```   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.percolate(index, percolate_request, async_req=True)
        >>> result = thread.get()

        :param index: Name of the percolate index (required)
        :type index: str
        :param percolate_request: (required)
        :type percolate_request: PercolateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SearchResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.percolate_with_http_info(index, percolate_request, **kwargs)  # noqa: E501

    def percolate_with_http_info(self, index, percolate_request, **kwargs):  # noqa: E501
        """Perform reverse search on a percolate index  # noqa: E501

        Performs a percolate search.  This method must be used only on percolate indexes.  Expects two parameters: the index name and an object with array of documents to be tested. An example of the documents object:    ```   {     \"query\":     {       \"percolate\":       {         \"document\":         {           \"content\":\"sample content\"         }       }     }   }   ```  Responds with an object with matched stored queries:     ```   {     'timed_out':false,     'hits':     {       'total':2,       'max_score':1,       'hits':       [         {           '_index':'idx_pq_1',           '_type':'doc',           '_id':'2',           '_score':'1',           '_source':           {             'query':             {               'match':{'title':'some'}             }           }         },         {           '_index':'idx_pq_1',           '_type':'doc',           '_id':'5',           '_score':'1',           '_source':           {             'query':             {               'ql':'some | none'             }           }         }       ]     }   }   ```   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.percolate_with_http_info(index, percolate_request, async_req=True)
        >>> result = thread.get()

        :param index: Name of the percolate index (required)
        :type index: str
        :param percolate_request: (required)
        :type percolate_request: PercolateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(SearchResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'index', 
            'percolate_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )
        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method percolate" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'index' is set
        if self.api_client.client_side_validation and ('index' not in local_var_params or  # noqa: E501
                                                        local_var_params['index'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `index` when calling `percolate`")  # noqa: E501
        # verify the required parameter 'percolate_request' is set
        if self.api_client.client_side_validation and ('percolate_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['percolate_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `percolate_request` when calling `percolate`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'index' in local_var_params:
            path_params['index'] = local_var_params['index']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'percolate_request' in local_var_params:
            body_params = local_var_params['percolate_request']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        res = self.api_client.call_api(
            '/pq/{index}/search', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SearchResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))
        return res
         

    def search(self, search_request, **kwargs):  # noqa: E501
        """Performs a search on an index  # noqa: E501

         The method expects an object with the following mandatory properties: * the name of the index to search * the match query object For details, see the documentation on [**SearchRequest**](SearchRequest.md) The method returns an object with the following properties: - took: the time taken to execute the search query. - timed_out: a boolean indicating whether the query timed out. - hits: an object with the following properties:    - total: the total number of hits found.    - hits: an array of hit objects, where each hit object represents a matched document. Each hit object has the following properties:      - _id: the ID of the matched document.      - _score: the score of the matched document.      - _source: the source data of the matched document.  In addition, if profiling is enabled, the response will include an additional array with profiling information attached. Here is an example search response:    ```   {     'took':10,     'timed_out':false,     'hits':     {       'total':2,       'hits':       [         {'_id':'1','_score':1,'_source':{'gid':11}},         {'_id':'2','_score':1,'_source':{'gid':12}}       ]     }   }   ```  For more information about the match query syntax and additional parameters that can be added to request and response, please see the documentation [here](https://manual.manticoresearch.com/Searching/Full_text_matching/Basic_usage#HTTP-JSON).   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.search(search_request, async_req=True)
        >>> result = thread.get()

        :param search_request: (required)
        :type search_request: SearchRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SearchResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.search_with_http_info(search_request, **kwargs)  # noqa: E501

    def search_with_http_info(self, search_request, **kwargs):  # noqa: E501
        """Performs a search on an index  # noqa: E501

         The method expects an object with the following mandatory properties: * the name of the index to search * the match query object For details, see the documentation on [**SearchRequest**](SearchRequest.md) The method returns an object with the following properties: - took: the time taken to execute the search query. - timed_out: a boolean indicating whether the query timed out. - hits: an object with the following properties:    - total: the total number of hits found.    - hits: an array of hit objects, where each hit object represents a matched document. Each hit object has the following properties:      - _id: the ID of the matched document.      - _score: the score of the matched document.      - _source: the source data of the matched document.  In addition, if profiling is enabled, the response will include an additional array with profiling information attached. Here is an example search response:    ```   {     'took':10,     'timed_out':false,     'hits':     {       'total':2,       'hits':       [         {'_id':'1','_score':1,'_source':{'gid':11}},         {'_id':'2','_score':1,'_source':{'gid':12}}       ]     }   }   ```  For more information about the match query syntax and additional parameters that can be added to request and response, please see the documentation [here](https://manual.manticoresearch.com/Searching/Full_text_matching/Basic_usage#HTTP-JSON).   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.search_with_http_info(search_request, async_req=True)
        >>> result = thread.get()

        :param search_request: (required)
        :type search_request: SearchRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(SearchResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'search_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )
        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method search" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'search_request' is set
        if self.api_client.client_side_validation and ('search_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['search_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `search_request` when calling `search`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'search_request' in local_var_params:
            body_params = local_var_params['search_request']
            if type(body_params) != dict:
                body_params = body_params.to_dict()
            body_params = dict(filter(lambda item: item[1] is not None, body_params.items() )) 

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        res = self.api_client.call_api(
            '/search', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SearchResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))
        return res
         



# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
#
# All rights reserved

import sys
import manticoresearch
import unittest
import importlib
import inspect
from parametrized_test_case import ParametrizedTestCase

configuration = manticoresearch.Configuration(
    host = "http://localhost:9408"
)

print
suite = unittest.TestSuite()
for module_name in ['test_manual']:
    test = importlib.import_module(module_name)
    for name, obj in inspect.getmembers(test):
        if inspect.isclass(obj) and obj.__name__ != 'ParametrizedTestCase':
            for p_class in inspect.getmro(obj):
                if p_class.__name__ == 'TestCase':
                    suite.addTest(ParametrizedTestCase.parametrize(obj, {'configuration': configuration}))
result = unittest.TextTestRunner(verbosity=2).run(suite)                    
sys.exit(not result.wasSuccessful())



# coding: utf-8

# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
# 
# All rights reserved
#



import pprint
import re  # noqa: F401

import six

from manticoresearch.configuration import Configuration

class SortMVA(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'attr': 'str',
        'order': 'str',
        'mode': 'str'
    }

    attribute_map = {
        'attr': 'attr',
        'order': 'order',
        'mode': 'mode'
    }

    def __init__(self, attr=None, order=None, mode=None, local_vars_configuration=None):  # noqa: E501
        """SortMVA - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._attr = None
        self._order = None
        self._mode = None
        self.discriminator = None

        self.attr = attr
        self.order = order
        self.mode = mode

    @property
    def attr(self):
        """Gets the attr of this SortMVA.  # noqa: E501


        :return: The attr of this SortMVA.  # noqa: E501
        :rtype: str
        """
        return self._attr
    @attr.setter
    def attr(self, attr):
        """Sets the attr of this SortMVA.


        :param attr: The attr of this SortMVA.  # noqa: E501
        :type attr: str
        """
        if self.local_vars_configuration.client_side_validation and attr is None:  # noqa: E501
            raise ValueError("Invalid value for `attr`, must not be `None`")  # noqa: E501

        self._attr = attr
        

    @property
    def order(self):
        """Gets the order of this SortMVA.  # noqa: E501


        :return: The order of this SortMVA.  # noqa: E501
        :rtype: str
        """
        return self._order
    @order.setter
    def order(self, order):
        """Sets the order of this SortMVA.


        :param order: The order of this SortMVA.  # noqa: E501
        :type order: str
        """
        if self.local_vars_configuration.client_side_validation and order is None:  # noqa: E501
            raise ValueError("Invalid value for `order`, must not be `None`")  # noqa: E501
        allowed_values = ["asc", "desc"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and order not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `order` ({0}), must be one of {1}"  # noqa: E501
                .format(order, allowed_values)
            )

        self._order = order
        

    @property
    def mode(self):
        """Gets the mode of this SortMVA.  # noqa: E501


        :return: The mode of this SortMVA.  # noqa: E501
        :rtype: str
        """
        return self._mode
    @mode.setter
    def mode(self, mode):
        """Sets the mode of this SortMVA.


        :param mode: The mode of this SortMVA.  # noqa: E501
        :type mode: str
        """
        if self.local_vars_configuration.client_side_validation and mode is None:  # noqa: E501
            raise ValueError("Invalid value for `mode`, must not be `None`")  # noqa: E501
        allowed_values = ["min", "max"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and mode not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `mode` ({0}), must be one of {1}"  # noqa: E501
                .format(mode, allowed_values)
            )

        self._mode = mode
        


    def to_dict(self):
        """Returns the model properties as a dict"""
        result = { self._attr: {'order': self._order, 'mode': self._mode} }




        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SortMVA):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SortMVA):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
# 
# All rights reserved
#



import pprint
import re  # noqa: F401

import six

from manticoresearch.configuration import Configuration

class BoolFilter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'should': '[{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]',
        'must': '[{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]',
        'must_not': '[{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]'
    }

    attribute_map = {
        'should': 'should',
        'must': 'must',
        'must_not': 'must_not'
    }

    def __init__(self, should=None, must=None, must_not=None, local_vars_configuration=None):  # noqa: E501
        """BoolFilter - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._should = None
        self._must = None
        self._must_not = None
        self.discriminator = None

        if should is not None:
            self.should = should
        if must is not None:
            self.must = must
        if must_not is not None:
            self.must_not = must_not

    @property
    def should(self):
        """Gets the should of this BoolFilter.  # noqa: E501


        :return: The should of this BoolFilter.  # noqa: E501
        :rtype: [{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]
        """
        return self._should
    @should.setter
    def should(self, should):
        """Sets the should of this BoolFilter.


        :param should: The should of this BoolFilter.  # noqa: E501
        :type should: [{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]
        """

        self._should = should
        

    @property
    def must(self):
        """Gets the must of this BoolFilter.  # noqa: E501


        :return: The must of this BoolFilter.  # noqa: E501
        :rtype: [{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]
        """
        return self._must
    @must.setter
    def must(self, must):
        """Sets the must of this BoolFilter.


        :param must: The must of this BoolFilter.  # noqa: E501
        :type must: [{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]
        """

        self._must = must
        

    @property
    def must_not(self):
        """Gets the must_not of this BoolFilter.  # noqa: E501


        :return: The must_not of this BoolFilter.  # noqa: E501
        :rtype: [{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]
        """
        return self._must_not
    @must_not.setter
    def must_not(self, must_not):
        """Sets the must_not of this BoolFilter.


        :param must_not: The must_not of this BoolFilter.  # noqa: E501
        :type must_not: [{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]
        """

        self._must_not = must_not
        


    def to_dict(self):
        """Returns the model properties as a dict"""

        result = {}		
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        result = { "bool": {k:v for k,v in result.items() if v is not None } }


        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BoolFilter):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BoolFilter):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Manticore Search Client

    Сlient for Manticore Search.   # noqa: E501

    The version of the OpenAPI document: 3.3.1
    Contact: info@manticoresearch.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "4.0.0"

# import apis into sdk package
from manticoresearch.api.index_api import IndexApi
from manticoresearch.api.search_api import SearchApi
from manticoresearch.api.utils_api import UtilsApi

# import ApiClient
from manticoresearch.api_client import ApiClient
from manticoresearch.configuration import Configuration
from manticoresearch.exceptions import OpenApiException
from manticoresearch.exceptions import ApiTypeError
from manticoresearch.exceptions import ApiValueError
from manticoresearch.exceptions import ApiKeyError
from manticoresearch.exceptions import ApiAttributeError
from manticoresearch.exceptions import ApiException
# import models into sdk package
from manticoresearch.model.aggregation import Aggregation
from manticoresearch.model.aggregation_sort_inner_value import AggregationSortInnerValue
from manticoresearch.model.aggregation_terms import AggregationTerms
from manticoresearch.model.attr_filter import AttrFilter
from manticoresearch.model.bool_filter import BoolFilter
from manticoresearch.model.bulk_response import BulkResponse
from manticoresearch.model.delete_document_request import DeleteDocumentRequest
from manticoresearch.model.delete_response import DeleteResponse
from manticoresearch.model.equals_filter import EqualsFilter
from manticoresearch.model.error_response import ErrorResponse
from manticoresearch.model.facet import Facet
from manticoresearch.model.filter_boolean import FilterBoolean
from manticoresearch.model.filter_number import FilterNumber
from manticoresearch.model.filter_string import FilterString
from manticoresearch.model.fulltext_filter import FulltextFilter
from manticoresearch.model.geo_distance_filter import GeoDistanceFilter
from manticoresearch.model.geo_distance_filter_location_anchor import GeoDistanceFilterLocationAnchor
from manticoresearch.model.highlight import Highlight
from manticoresearch.model.highlight_field import HighlightField
from manticoresearch.model.in_filter import InFilter
from manticoresearch.model.insert_document_request import InsertDocumentRequest
from manticoresearch.model.knn_query_by_doc_id import KnnQueryByDocId
from manticoresearch.model.knn_query_by_vector import KnnQueryByVector
from manticoresearch.model.match_filter import MatchFilter
from manticoresearch.model.match_op import MatchOp
from manticoresearch.model.match_op_filter import MatchOpFilter
from manticoresearch.model.match_phrase_filter import MatchPhraseFilter
from manticoresearch.model.not_filter_boolean import NotFilterBoolean
from manticoresearch.model.not_filter_number import NotFilterNumber
from manticoresearch.model.not_filter_string import NotFilterString
from manticoresearch.model.option import Option
from manticoresearch.model.percolate_request import PercolateRequest
from manticoresearch.model.percolate_request_query import PercolateRequestQuery
from manticoresearch.model.query_filter import QueryFilter
from manticoresearch.model.range_filter import RangeFilter
from manticoresearch.model.replace_document_request import ReplaceDocumentRequest
from manticoresearch.model.search_request import SearchRequest
from manticoresearch.model.search_request_knn import SearchRequestKnn
from manticoresearch.model.search_response import SearchResponse
from manticoresearch.model.search_response_hits import SearchResponseHits
from manticoresearch.model.sort_mva import SortMVA
from manticoresearch.model.sort_multiple import SortMultiple
from manticoresearch.model.sort_order import SortOrder
from manticoresearch.model.source_by_rules import SourceByRules
from manticoresearch.model.source_multiple import SourceMultiple
from manticoresearch.model.sql_response import SqlResponse
from manticoresearch.model.success_response import SuccessResponse
from manticoresearch.model.update_document_request import UpdateDocumentRequest
from manticoresearch.model.update_response import UpdateResponse




# coding: utf-8

# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
# 
# All rights reserved
#



import pprint
import re  # noqa: F401

import six

from manticoresearch.configuration import Configuration

class DeleteResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'index': 'str',
        'deleted': 'int',
        'id': 'int',
        'result': 'str'
    }

    attribute_map = {
        'index': '_index',
        'deleted': 'deleted',
        'id': '_id',
        'result': 'result'
    }

    def __init__(self, index=None, deleted=None, id=None, result=None, local_vars_configuration=None):  # noqa: E501
        """DeleteResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._index = None
        self._deleted = None
        self._id = None
        self._result = None
        self.discriminator = None

        if index is not None:
            self.index = index
        if deleted is not None:
            self.deleted = deleted
        if id is not None:
            self.id = id
        if result is not None:
            self.result = result

    @property
    def index(self):
        """Gets the index of this DeleteResponse.  # noqa: E501


        :return: The index of this DeleteResponse.  # noqa: E501
        :rtype: str
        """
        return self._index
    @index.setter
    def index(self, index):
        """Sets the index of this DeleteResponse.


        :param index: The index of this DeleteResponse.  # noqa: E501
        :type index: str
        """

        self._index = index
        

    @property
    def deleted(self):
        """Gets the deleted of this DeleteResponse.  # noqa: E501


        :return: The deleted of this DeleteResponse.  # noqa: E501
        :rtype: int
        """
        return self._deleted
    @deleted.setter
    def deleted(self, deleted):
        """Sets the deleted of this DeleteResponse.


        :param deleted: The deleted of this DeleteResponse.  # noqa: E501
        :type deleted: int
        """

        self._deleted = deleted
        

    @property
    def id(self):
        """Gets the id of this DeleteResponse.  # noqa: E501


        :return: The id of this DeleteResponse.  # noqa: E501
        :rtype: int
        """
        return self._id
    @id.setter
    def id(self, id):
        """Sets the id of this DeleteResponse.


        :param id: The id of this DeleteResponse.  # noqa: E501
        :type id: int
        """

        self._id = id
        

    @property
    def result(self):
        """Gets the result of this DeleteResponse.  # noqa: E501


        :return: The result of this DeleteResponse.  # noqa: E501
        :rtype: str
        """
        return self._result
    @result.setter
    def result(self, result):
        """Sets the result of this DeleteResponse.


        :param result: The result of this DeleteResponse.  # noqa: E501
        :type result: str
        """

        self._result = result
        


    def to_dict(self):
        """Returns the model properties as a dict"""

        result = {}		
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value



        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeleteResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
# 
# All rights reserved
#



import pprint
import re  # noqa: F401

import six

from manticoresearch.configuration import Configuration

class NotFilterString(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'filter_field': 'str',
        'operation': 'str',
        'filter_value': 'str'
    }

    attribute_map = {
        'filter_field': 'filter_field',
        'operation': 'operation',
        'filter_value': 'filter_value'
    }

    def __init__(self, filter_field=None, operation=None, filter_value=None, local_vars_configuration=None):  # noqa: E501
        """NotFilterString - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._filter_field = None
        self._operation = None
        self._filter_value = None
        self.discriminator = None

        self.filter_field = filter_field
        self.operation = operation
        self.filter_value = filter_value

    @property
    def filter_field(self):
        """Gets the filter_field of this NotFilterString.  # noqa: E501


        :return: The filter_field of this NotFilterString.  # noqa: E501
        :rtype: str
        """
        return self._filter_field
    @filter_field.setter
    def filter_field(self, filter_field):
        """Sets the filter_field of this NotFilterString.


        :param filter_field: The filter_field of this NotFilterString.  # noqa: E501
        :type filter_field: str
        """
        if self.local_vars_configuration.client_side_validation and filter_field is None:  # noqa: E501
            raise ValueError("Invalid value for `filter_field`, must not be `None`")  # noqa: E501

        self._filter_field = filter_field
        

    @property
    def operation(self):
        """Gets the operation of this NotFilterString.  # noqa: E501


        :return: The operation of this NotFilterString.  # noqa: E501
        :rtype: str
        """
        return self._operation
    @operation.setter
    def operation(self, operation):
        """Sets the operation of this NotFilterString.


        :param operation: The operation of this NotFilterString.  # noqa: E501
        :type operation: str
        """
        if self.local_vars_configuration.client_side_validation and operation is None:  # noqa: E501
            raise ValueError("Invalid value for `operation`, must not be `None`")  # noqa: E501

        self._operation = operation
        

    @property
    def filter_value(self):
        """Gets the filter_value of this NotFilterString.  # noqa: E501


        :return: The filter_value of this NotFilterString.  # noqa: E501
        :rtype: str
        """
        return self._filter_value
    @filter_value.setter
    def filter_value(self, filter_value):
        """Sets the filter_value of this NotFilterString.


        :param filter_value: The filter_value of this NotFilterString.  # noqa: E501
        :type filter_value: str
        """
        if self.local_vars_configuration.client_side_validation and filter_value is None:  # noqa: E501
            raise ValueError("Invalid value for `filter_value`, must not be `None`")  # noqa: E501

        self._filter_value = filter_value
        


    def to_dict(self):
        """Returns the model properties as a dict"""

        result = {}		
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value



        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NotFilterString):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NotFilterString):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
# 
# All rights reserved
#



import pprint
import re  # noqa: F401

import six

from manticoresearch.configuration import Configuration

class Highlight(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'fieldnames': '[str]',
        'fields': '[HighlightField]',
        'encoder': 'str',
        'highlight_query': '{str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type',
        'pre_tags': 'str',
        'post_tags': 'str',
        'no_match_size': 'int',
        'fragment_size': 'int',
        'number_of_fragments': 'int',
        'limit': 'int',
        'limit_words': 'int',
        'limit_snippets': 'int',
        'limits_per_field': 'bool',
        'use_boundaries': 'bool',
        'force_all_words': 'bool',
        'allow_empty': 'bool',
        'emit_zones': 'bool',
        'force_snippets': 'bool',
        'around': 'int',
        'start_snippet_id': 'int',
        'html_strip_mode': 'str',
        'snippet_boundary': 'str'
    }

    attribute_map = {
        'fieldnames': 'fieldnames',
        'fields': 'fields',
        'encoder': 'encoder',
        'highlight_query': 'highlight_query',
        'pre_tags': 'pre_tags',
        'post_tags': 'post_tags',
        'no_match_size': 'no_match_size',
        'fragment_size': 'fragment_size',
        'number_of_fragments': 'number_of_fragments',
        'limit': 'limit',
        'limit_words': 'limit_words',
        'limit_snippets': 'limit_snippets',
        'limits_per_field': 'limits_per_field',
        'use_boundaries': 'use_boundaries',
        'force_all_words': 'force_all_words',
        'allow_empty': 'allow_empty',
        'emit_zones': 'emit_zones',
        'force_snippets': 'force_snippets',
        'around': 'around',
        'start_snippet_id': 'start_snippet_id',
        'html_strip_mode': 'html_strip_mode',
        'snippet_boundary': 'snippet_boundary'
    }

    def __init__(self, fieldnames=None, fields=None, encoder=None, highlight_query=None, pre_tags="<strong>", post_tags="</strong>", no_match_size=None, fragment_size=256, number_of_fragments=0, limit=256, limit_words=0, limit_snippets=0, limits_per_field=False, use_boundaries=False, force_all_words=False, allow_empty=False, emit_zones=False, force_snippets=False, around=5, start_snippet_id=1, html_strip_mode=None, snippet_boundary=None, local_vars_configuration=None):  # noqa: E501
        """Highlight - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._fieldnames = None
        self._fields = None
        self._encoder = None
        self._highlight_query = None
        self._pre_tags = None
        self._post_tags = None
        self._no_match_size = None
        self._fragment_size = None
        self._number_of_fragments = None
        self._limit = None
        self._limit_words = None
        self._limit_snippets = None
        self._limits_per_field = None
        self._use_boundaries = None
        self._force_all_words = None
        self._allow_empty = None
        self._emit_zones = None
        self._force_snippets = None
        self._around = None
        self._start_snippet_id = None
        self._html_strip_mode = None
        self._snippet_boundary = None
        self.discriminator = None

        if fieldnames is not None:
            self.fieldnames = fieldnames
        if fields is not None:
            self.fields = fields
        if encoder is not None:
            self.encoder = encoder
        self.highlight_query = highlight_query
        if pre_tags is not None:
            self.pre_tags = pre_tags
        if post_tags is not None:
            self.post_tags = post_tags
        if no_match_size is not None:
            self.no_match_size = no_match_size
        if fragment_size is not None:
            self.fragment_size = fragment_size
        if number_of_fragments is not None:
            self.number_of_fragments = number_of_fragments
        if limit is not None:
            self.limit = limit
        if limit_words is not None:
            self.limit_words = limit_words
        if limit_snippets is not None:
            self.limit_snippets = limit_snippets
        if limits_per_field is not None:
            self.limits_per_field = limits_per_field
        if use_boundaries is not None:
            self.use_boundaries = use_boundaries
        if force_all_words is not None:
            self.force_all_words = force_all_words
        if allow_empty is not None:
            self.allow_empty = allow_empty
        if emit_zones is not None:
            self.emit_zones = emit_zones
        if force_snippets is not None:
            self.force_snippets = force_snippets
        if around is not None:
            self.around = around
        if start_snippet_id is not None:
            self.start_snippet_id = start_snippet_id
        if html_strip_mode is not None:
            self.html_strip_mode = html_strip_mode
        if snippet_boundary is not None:
            self.snippet_boundary = snippet_boundary

    @property
    def fieldnames(self):
        """Gets the fieldnames of this Highlight.  # noqa: E501


        :return: The fieldnames of this Highlight.  # noqa: E501
        :rtype: [str]
        """
        return self._fieldnames
    @fieldnames.setter
    def fieldnames(self, fieldnames):
        """Sets the fieldnames of this Highlight.


        :param fieldnames: The fieldnames of this Highlight.  # noqa: E501
        :type fieldnames: [str]
        """

        self._fieldnames = fieldnames
        

    @property
    def fields(self):
        """Gets the fields of this Highlight.  # noqa: E501


        :return: The fields of this Highlight.  # noqa: E501
        :rtype: [HighlightField]
        """
        return self._fields
    @fields.setter
    def fields(self, fields):
        """Sets the fields of this Highlight.


        :param fields: The fields of this Highlight.  # noqa: E501
        :type fields: [HighlightField]
        """

        self._fields = fields
        

    @property
    def encoder(self):
        """Gets the encoder of this Highlight.  # noqa: E501


        :return: The encoder of this Highlight.  # noqa: E501
        :rtype: str
        """
        return self._encoder
    @encoder.setter
    def encoder(self, encoder):
        """Sets the encoder of this Highlight.


        :param encoder: The encoder of this Highlight.  # noqa: E501
        :type encoder: str
        """
        allowed_values = ["default", "html"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and encoder not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `encoder` ({0}), must be one of {1}"  # noqa: E501
                .format(encoder, allowed_values)
            )

        self._encoder = encoder
        

    @property
    def highlight_query(self):
        """Gets the highlight_query of this Highlight.  # noqa: E501


        :return: The highlight_query of this Highlight.  # noqa: E501
        :rtype: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type
        """
        return self._highlight_query
    @highlight_query.setter
    def highlight_query(self, highlight_query):
        """Sets the highlight_query of this Highlight.


        :param highlight_query: The highlight_query of this Highlight.  # noqa: E501
        :type highlight_query: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}, none_type
        """

        self._highlight_query = highlight_query
        

    @property
    def pre_tags(self):
        """Gets the pre_tags of this Highlight.  # noqa: E501


        :return: The pre_tags of this Highlight.  # noqa: E501
        :rtype: str
        """
        return self._pre_tags
    @pre_tags.setter
    def pre_tags(self, pre_tags):
        """Sets the pre_tags of this Highlight.


        :param pre_tags: The pre_tags of this Highlight.  # noqa: E501
        :type pre_tags: str
        """

        self._pre_tags = pre_tags
        

    @property
    def post_tags(self):
        """Gets the post_tags of this Highlight.  # noqa: E501


        :return: The post_tags of this Highlight.  # noqa: E501
        :rtype: str
        """
        return self._post_tags
    @post_tags.setter
    def post_tags(self, post_tags):
        """Sets the post_tags of this Highlight.


        :param post_tags: The post_tags of this Highlight.  # noqa: E501
        :type post_tags: str
        """

        self._post_tags = post_tags
        

    @property
    def no_match_size(self):
        """Gets the no_match_size of this Highlight.  # noqa: E501


        :return: The no_match_size of this Highlight.  # noqa: E501
        :rtype: int
        """
        return self._no_match_size
    @no_match_size.setter
    def no_match_size(self, no_match_size):
        """Sets the no_match_size of this Highlight.


        :param no_match_size: The no_match_size of this Highlight.  # noqa: E501
        :type no_match_size: int
        """
        allowed_values = [0, 1]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and no_match_size not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `no_match_size` ({0}), must be one of {1}"  # noqa: E501
                .format(no_match_size, allowed_values)
            )

        self._no_match_size = no_match_size
        

    @property
    def fragment_size(self):
        """Gets the fragment_size of this Highlight.  # noqa: E501


        :return: The fragment_size of this Highlight.  # noqa: E501
        :rtype: int
        """
        return self._fragment_size
    @fragment_size.setter
    def fragment_size(self, fragment_size):
        """Sets the fragment_size of this Highlight.


        :param fragment_size: The fragment_size of this Highlight.  # noqa: E501
        :type fragment_size: int
        """

        self._fragment_size = fragment_size
        

    @property
    def number_of_fragments(self):
        """Gets the number_of_fragments of this Highlight.  # noqa: E501


        :return: The number_of_fragments of this Highlight.  # noqa: E501
        :rtype: int
        """
        return self._number_of_fragments
    @number_of_fragments.setter
    def number_of_fragments(self, number_of_fragments):
        """Sets the number_of_fragments of this Highlight.


        :param number_of_fragments: The number_of_fragments of this Highlight.  # noqa: E501
        :type number_of_fragments: int
        """

        self._number_of_fragments = number_of_fragments
        

    @property
    def limit(self):
        """Gets the limit of this Highlight.  # noqa: E501


        :return: The limit of this Highlight.  # noqa: E501
        :rtype: int
        """
        return self._limit
    @limit.setter
    def limit(self, limit):
        """Sets the limit of this Highlight.


        :param limit: The limit of this Highlight.  # noqa: E501
        :type limit: int
        """

        self._limit = limit
        

    @property
    def limit_words(self):
        """Gets the limit_words of this Highlight.  # noqa: E501


        :return: The limit_words of this Highlight.  # noqa: E501
        :rtype: int
        """
        return self._limit_words
    @limit_words.setter
    def limit_words(self, limit_words):
        """Sets the limit_words of this Highlight.


        :param limit_words: The limit_words of this Highlight.  # noqa: E501
        :type limit_words: int
        """

        self._limit_words = limit_words
        

    @property
    def limit_snippets(self):
        """Gets the limit_snippets of this Highlight.  # noqa: E501


        :return: The limit_snippets of this Highlight.  # noqa: E501
        :rtype: int
        """
        return self._limit_snippets
    @limit_snippets.setter
    def limit_snippets(self, limit_snippets):
        """Sets the limit_snippets of this Highlight.


        :param limit_snippets: The limit_snippets of this Highlight.  # noqa: E501
        :type limit_snippets: int
        """

        self._limit_snippets = limit_snippets
        

    @property
    def limits_per_field(self):
        """Gets the limits_per_field of this Highlight.  # noqa: E501


        :return: The limits_per_field of this Highlight.  # noqa: E501
        :rtype: bool
        """
        return self._limits_per_field
    @limits_per_field.setter
    def limits_per_field(self, limits_per_field):
        """Sets the limits_per_field of this Highlight.


        :param limits_per_field: The limits_per_field of this Highlight.  # noqa: E501
        :type limits_per_field: bool
        """

        self._limits_per_field = limits_per_field
        

    @property
    def use_boundaries(self):
        """Gets the use_boundaries of this Highlight.  # noqa: E501


        :return: The use_boundaries of this Highlight.  # noqa: E501
        :rtype: bool
        """
        return self._use_boundaries
    @use_boundaries.setter
    def use_boundaries(self, use_boundaries):
        """Sets the use_boundaries of this Highlight.


        :param use_boundaries: The use_boundaries of this Highlight.  # noqa: E501
        :type use_boundaries: bool
        """

        self._use_boundaries = use_boundaries
        

    @property
    def force_all_words(self):
        """Gets the force_all_words of this Highlight.  # noqa: E501


        :return: The force_all_words of this Highlight.  # noqa: E501
        :rtype: bool
        """
        return self._force_all_words
    @force_all_words.setter
    def force_all_words(self, force_all_words):
        """Sets the force_all_words of this Highlight.


        :param force_all_words: The force_all_words of this Highlight.  # noqa: E501
        :type force_all_words: bool
        """

        self._force_all_words = force_all_words
        

    @property
    def allow_empty(self):
        """Gets the allow_empty of this Highlight.  # noqa: E501


        :return: The allow_empty of this Highlight.  # noqa: E501
        :rtype: bool
        """
        return self._allow_empty
    @allow_empty.setter
    def allow_empty(self, allow_empty):
        """Sets the allow_empty of this Highlight.


        :param allow_empty: The allow_empty of this Highlight.  # noqa: E501
        :type allow_empty: bool
        """

        self._allow_empty = allow_empty
        

    @property
    def emit_zones(self):
        """Gets the emit_zones of this Highlight.  # noqa: E501


        :return: The emit_zones of this Highlight.  # noqa: E501
        :rtype: bool
        """
        return self._emit_zones
    @emit_zones.setter
    def emit_zones(self, emit_zones):
        """Sets the emit_zones of this Highlight.


        :param emit_zones: The emit_zones of this Highlight.  # noqa: E501
        :type emit_zones: bool
        """

        self._emit_zones = emit_zones
        

    @property
    def force_snippets(self):
        """Gets the force_snippets of this Highlight.  # noqa: E501


        :return: The force_snippets of this Highlight.  # noqa: E501
        :rtype: bool
        """
        return self._force_snippets
    @force_snippets.setter
    def force_snippets(self, force_snippets):
        """Sets the force_snippets of this Highlight.


        :param force_snippets: The force_snippets of this Highlight.  # noqa: E501
        :type force_snippets: bool
        """

        self._force_snippets = force_snippets
        

    @property
    def around(self):
        """Gets the around of this Highlight.  # noqa: E501


        :return: The around of this Highlight.  # noqa: E501
        :rtype: int
        """
        return self._around
    @around.setter
    def around(self, around):
        """Sets the around of this Highlight.


        :param around: The around of this Highlight.  # noqa: E501
        :type around: int
        """

        self._around = around
        

    @property
    def start_snippet_id(self):
        """Gets the start_snippet_id of this Highlight.  # noqa: E501


        :return: The start_snippet_id of this Highlight.  # noqa: E501
        :rtype: int
        """
        return self._start_snippet_id
    @start_snippet_id.setter
    def start_snippet_id(self, start_snippet_id):
        """Sets the start_snippet_id of this Highlight.


        :param start_snippet_id: The start_snippet_id of this Highlight.  # noqa: E501
        :type start_snippet_id: int
        """

        self._start_snippet_id = start_snippet_id
        

    @property
    def html_strip_mode(self):
        """Gets the html_strip_mode of this Highlight.  # noqa: E501


        :return: The html_strip_mode of this Highlight.  # noqa: E501
        :rtype: str
        """
        return self._html_strip_mode
    @html_strip_mode.setter
    def html_strip_mode(self, html_strip_mode):
        """Sets the html_strip_mode of this Highlight.


        :param html_strip_mode: The html_strip_mode of this Highlight.  # noqa: E501
        :type html_strip_mode: str
        """
        allowed_values = ["none", "strip", "index", "retain"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and html_strip_mode not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `html_strip_mode` ({0}), must be one of {1}"  # noqa: E501
                .format(html_strip_mode, allowed_values)
            )

        self._html_strip_mode = html_strip_mode
        

    @property
    def snippet_boundary(self):
        """Gets the snippet_boundary of this Highlight.  # noqa: E501


        :return: The snippet_boundary of this Highlight.  # noqa: E501
        :rtype: str
        """
        return self._snippet_boundary
    @snippet_boundary.setter
    def snippet_boundary(self, snippet_boundary):
        """Sets the snippet_boundary of this Highlight.


        :param snippet_boundary: The snippet_boundary of this Highlight.  # noqa: E501
        :type snippet_boundary: str
        """
        allowed_values = ["sentence", "paragraph", "zone"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and snippet_boundary not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `snippet_boundary` ({0}), must be one of {1}"  # noqa: E501
                .format(snippet_boundary, allowed_values)
            )

        self._snippet_boundary = snippet_boundary
        


    def to_dict(self):
        """Returns the model properties as a dict"""

        result = {}		
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        if result['fields'] is not None:
            result['fields'] = {k:v for i in result['fields'] for k,v in i.items() if v is not None}


        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Highlight):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Highlight):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
# 
# All rights reserved
#



import pprint
import re  # noqa: F401

import six

from manticoresearch.configuration import Configuration

class InFilter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'field': 'str',
        'values': '[{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]'
    }

    attribute_map = {
        'field': 'field',
        'values': 'values'
    }

    def __init__(self, field=None, values=None, local_vars_configuration=None):  # noqa: E501
        """InFilter - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._field = None
        self._values = None
        self.discriminator = None

        self.field = field
        self.values = values

    @property
    def field(self):
        """Gets the field of this InFilter.  # noqa: E501


        :return: The field of this InFilter.  # noqa: E501
        :rtype: str
        """
        return self._field
    @field.setter
    def field(self, field):
        """Sets the field of this InFilter.


        :param field: The field of this InFilter.  # noqa: E501
        :type field: str
        """
        if self.local_vars_configuration.client_side_validation and field is None:  # noqa: E501
            raise ValueError("Invalid value for `field`, must not be `None`")  # noqa: E501

        self._field = field
        

    @property
    def values(self):
        """Gets the values of this InFilter.  # noqa: E501


        :return: The values of this InFilter.  # noqa: E501
        :rtype: [{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]
        """
        return self._values
    @values.setter
    def values(self, values):
        """Sets the values of this InFilter.


        :param values: The values of this InFilter.  # noqa: E501
        :type values: [{str: (bool, date, datetime, dict, float, int, list, str, none_type)}]
        """
        if self.local_vars_configuration.client_side_validation and values is None:  # noqa: E501
            raise ValueError("Invalid value for `values`, must not be `None`")  # noqa: E501

        self._values = values
        


    def to_dict(self):
        """Returns the model properties as a dict"""
        result = { 'in': {self._field: self._values } }




        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InFilter):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InFilter):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8
# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
#
# All rights reserved

"""
    Manticore Search API

    This is the API for Manticore Search HTTP protocol   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: info@manticoresearch.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import
from pprint import pprint
import unittest
import manticoresearch
from manticoresearch.api.index_api import IndexApi  # noqa: E501
from manticoresearch.rest import ApiException
from parametrized_test_case import ParametrizedTestCase

class TestIndexApi(ParametrizedTestCase):
    """IndexApi unit test stubs"""

    def setUp(self):
        self.api = manticoresearch.IndexApi(manticoresearch.ApiClient(self.settings['configuration']))  # noqa: E501
        
    def tearDown(self):
        pass

    def test_bulk(self):
        self.assertTrue(True)
        
    def test_delete(self):
        """Test case for delete
 
        Delete a document in an index  # noqa: E501
        """
        
        req_body = {"index":"test","id":1} 
        api_resp = self.api.delete(req_body)
        req_body = {"index":"test","id":2} 
        api_resp = self.api.delete(req_body)
        
        req_body = {"index":"test","id":3} 
        api_resp = self.api.delete(req_body)
        res = {'deleted':  api_resp.deleted, 'id': api_resp.id, 'index': api_resp.index, 'result': api_resp.result}
        expected_res = {'deleted': None, 'id': 3, 'index': 'test', 'result': 'not found'}
        self.assertDictEqual(res, expected_res)
        
        req_body = {"index":"test","query":{"match":{"content":"no match"}}} 
        api_resp = self.api.delete(req_body)
        res = {'deleted':  api_resp.deleted, 'id': api_resp.id, 'index': api_resp.index, 'result': api_resp.result}
        expected_res = {'deleted': 0, 'id': None, 'index': 'test', 'result': None}
        self.assertDictEqual(res, expected_res)
         
        insert_req_body = {"index":"test","id":1,"doc":{"content":"sample content","name":"test doc","cat":"10"}} 
        self.api.insert(insert_req_body)
        req_body = {"index":"test","id":1} 
        api_resp = self.api.delete(req_body)
        res = {'deleted':  api_resp.deleted, 'id': api_resp.id, 'index': api_resp.index, 'result': api_resp.result}
        expected_res = {'deleted': None, 'id': 1, 'index': 'test', 'result': 'deleted'}
        self.assertDictEqual(res, expected_res) 
        
        self.api.insert(insert_req_body)
        req_body = {"index":"test","query":{"match":{"content":"sample content"}}} 
        api_resp = self.api.delete(req_body)
        res = {'deleted':  api_resp.deleted, 'id': api_resp.id, 'index': api_resp.index, 'result': api_resp.result}
        expected_res = {'deleted': 1, 'id': None, 'index': 'test', 'result': None}        
        self.assertDictEqual(res, expected_res)
    
    def test_insert(self):
        """Test case for insert
   
        Create a new document in an index  # noqa: E501
        """
        req_body = {"index":"test","id":1,"doc":{"content":"sample content","name":"test doc","cat":"10"}} 
        api_resp = self.api.insert(req_body)
        res = {'created':  api_resp.created, 'found': api_resp.found, 'id': api_resp.id, 'index': api_resp.index, 'result': api_resp.result}
        expected_res = {'created': True, 'found': None, 'id': 1, 'index': 'test', 'result': 'created'}
        self.assertDictEqual(res, expected_res) 

    def test_replace(self):
        """Test case for replace
 
        Replace new document in an index  # noqa: E501
        """
        req_body = {"index":"test","id":2,"doc":{"content":"content updated","cat":11}} 
        api_resp = self.api.replace(req_body)
        res = {'created':  api_resp.created, 'found': api_resp.found, 'id': api_resp.id, 'index': api_resp.index, 'result': api_resp.result}
        expected_res = {'created': False, 'found': None, 'id': 2, 'index': 'test', 'result': 'updated'}
        self.assertDictEqual(res, expected_res)
        
        req_body = {"index":"test","id":1,"doc":{"content":"content updated","name":"test doc","cat":11}} 
        api_resp = self.api.replace(req_body)
        res = {'created':  api_resp.created, 'found': api_resp.found, 'id': api_resp.id, 'index': api_resp.index, 'result': api_resp.result}
        expected_res = {'created': False, 'found': None, 'id': 1, 'index': 'test', 'result': 'updated'}
        self.assertDictEqual(res, expected_res)
        pass
 
    def test_update(self):
        """Test case for update

        Update a document in an index  # noqa: E501
        """
        req_body = {"index":"test","doc":{"cat":12},"query":{"equals":{"name":"no match"}}}
        api_resp = self.api.update(req_body)
        res = {'index': api_resp.index, 'result': api_resp.result, 'updated': api_resp.updated}
        expected_res = {'index': 'test', 'result': None, 'updated': 0}
        self.assertDictEqual(res, expected_res)
 
        req_body = {"index":"test","id":3, "doc":{"cat":13}} 
        api_resp = self.api.update(req_body)
        res = {'id': api_resp.id, 'index': api_resp.index, 'result': api_resp.result, 'updated': api_resp.updated}
        expected_res = {'id': 3, 'index': 'test', 'result': 'noop', 'updated': None}
        self.assertDictEqual(res, expected_res)
        
         
        req_body = {"index":"test","id":1, "doc":{"cat":11}} 
        api_resp = self.api.update(req_body)
        res = {'id': api_resp.id, 'index': api_resp.index, 'result': api_resp.result, 'updated': api_resp.updated}
        expected_res = {'id': 1, 'index': 'test', 'result': 'updated', 'updated': None}
        self.assertDictEqual(res, expected_res)
         
        req_body = {"index":"test","doc":{"cat":12},"query":{"equals":{"name":"test doc"}}}
        api_resp = self.api.update(req_body)
        res = {'index': api_resp.index, 'result': api_resp.result, 'updated': api_resp.updated}
        expected_res = {'index': 'test', 'result': None, 'updated': 1}
        self.assertDictEqual(res, expected_res) 

if __name__ == '__main__':
    unittest.main()



# coding: utf-8
# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
#
# All rights reserved

"""
    Manticore Search API

    This is the API for Manticore Search HTTP protocol   # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: info@manticoresearch.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import
from pprint import pprint
import unittest
import manticoresearch
from manticoresearch.api.search_api import SearchApi  # noqa: E501
from manticoresearch.rest import ApiException
from parametrized_test_case import ParametrizedTestCase

class TestSearchApi(ParametrizedTestCase):
    """SearchApi unit test stubs"""

    def setUp(self):
        client = manticoresearch.ApiClient(self.settings['configuration'])
        self.api = manticoresearch.SearchApi(client)  # noqa: E501
        self.index_api = manticoresearch.IndexApi(client)  # noqa: E501

    def tearDown(self):
        pass

    def test_percolate(self):
        """Test case for percolate

        Perform reverse search on a percolate index  # noqa: E501
        """
        self.index_api.insert({"index":"test_pq","id":1,"doc":{"query":"@content sample content"}})
        req_body = {"query":{"percolate":{"document":{"content":"sample content"}}}} 
        api_resp = self.api.percolate("test_pq", req_body)
        res = {'hits': api_resp.hits.hits, 'total': api_resp.hits.total, 'profile': api_resp.profile, 'timed_out': api_resp.timed_out}
        expected_res = {'hits': [{'_id': '1', '_index': 'test_pq', '_score': '1', '_source': {'query': {'ql': '@content sample content'}}, '_type': 'doc', 'fields': {'_percolator_document_slot': [1]}}], 'total': 1, 'profile': None, 'timed_out': False}
        self.assertDictEqual(res, expected_res)
         
        req_body = {"query":{"percolate":{"document":{"content":"no match"}}}} 
        api_resp = self.api.percolate("test_pq", req_body)
        res = {'hits': api_resp.hits.hits, 'total': api_resp.hits.total, 'profile': api_resp.profile, 'timed_out': api_resp.timed_out}
        expected_res = {'hits': [], 'total': 0, 'profile': None, 'timed_out': False}
        self.assertDictEqual(res, expected_res)
        pass

    def test_search(self):
        """Test case for search

        Performs a search  # noqa: E501
        """
        req_body = {"index":"test","id":1} 
        api_resp = self.index_api.delete(req_body)
        insert_req_body = {"index":"test","id":1,"doc":{"content":"sample content","name":"test doc","cat":"10"}} 
        self.index_api.insert(insert_req_body)
        req_body = {"index":"test","query":{"match":{"content":"sample"}}} 
        api_resp = self.api.search(req_body)
        res = {'id': api_resp.hits.hits[0]['_id'], 'total': api_resp.hits.total, 'profile': api_resp.profile, 'timed_out': api_resp.timed_out}
        expected_res = {'id': '1', 'total': 1, 'profile': None, 'timed_out': False}
        self.assertDictEqual(res, expected_res)
        
        req_body = {"index":"test","query":{"match":{"content":"no match"}}} 
        api_resp = self.api.search(req_body)
        res = {'hits': api_resp.hits.hits, 'total': api_resp.hits.total, 'profile': api_resp.profile, 'timed_out': api_resp.timed_out}
        expected_res = {'hits': [], 'total': 0, 'profile': None, 'timed_out': False}
        self.assertDictEqual(res, expected_res)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
# 
# All rights reserved
#



from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six
from six.moves.urllib.parse import quote

from manticoresearch.api_client import ApiClient
from manticoresearch.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class IndexApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def bulk(self, body, **kwargs):  # noqa: E501
        """Bulk index operations  # noqa: E501

        Sends multiple operatons like inserts, updates, replaces or deletes.  For each operation it's object must have same format as in their dedicated method.  The method expects a raw string as the batch in NDJSON.  Each operation object needs to be serialized to   JSON and separated by endline (\\n).      An example of raw input:      ```   {\"insert\": {\"index\": \"movies\", \"doc\": {\"plot\": \"A secret team goes to North Pole\", \"rating\": 9.5, \"language\": [2, 3], \"title\": \"This is an older movie\", \"lon\": 51.99, \"meta\": {\"keywords\":[\"travel\",\"ice\"],\"genre\":[\"adventure\"]}, \"year\": 1950, \"lat\": 60.4, \"advise\": \"PG-13\"}}}   \\n   {\"delete\": {\"index\": \"movies\",\"id\":700}}   ```      Responds with an object telling whenever any errors occured and an array with status for each operation:      ```   {     'items':     [       {         'update':{'_index':'products','_id':1,'result':'updated'}       },       {         'update':{'_index':'products','_id':2,'result':'updated'}       }     ],     'errors':false   }   ```     # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.bulk(body, async_req=True)
        >>> result = thread.get()

        :param body: (required)
        :type body: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BulkResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.bulk_with_http_info(body, **kwargs)  # noqa: E501

    def bulk_with_http_info(self, body, **kwargs):  # noqa: E501
        """Bulk index operations  # noqa: E501

        Sends multiple operatons like inserts, updates, replaces or deletes.  For each operation it's object must have same format as in their dedicated method.  The method expects a raw string as the batch in NDJSON.  Each operation object needs to be serialized to   JSON and separated by endline (\\n).      An example of raw input:      ```   {\"insert\": {\"index\": \"movies\", \"doc\": {\"plot\": \"A secret team goes to North Pole\", \"rating\": 9.5, \"language\": [2, 3], \"title\": \"This is an older movie\", \"lon\": 51.99, \"meta\": {\"keywords\":[\"travel\",\"ice\"],\"genre\":[\"adventure\"]}, \"year\": 1950, \"lat\": 60.4, \"advise\": \"PG-13\"}}}   \\n   {\"delete\": {\"index\": \"movies\",\"id\":700}}   ```      Responds with an object telling whenever any errors occured and an array with status for each operation:      ```   {     'items':     [       {         'update':{'_index':'products','_id':1,'result':'updated'}       },       {         'update':{'_index':'products','_id':2,'result':'updated'}       }     ],     'errors':false   }   ```     # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.bulk_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param body: (required)
        :type body: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(BulkResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )
        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method bulk" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `bulk`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/x-ndjson'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        res = self.api_client.call_api(
            '/bulk', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BulkResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))
        return res
         

    def delete(self, delete_document_request, **kwargs):  # noqa: E501
        """Delete a document in an index  # noqa: E501

        Delete one or several documents. The method has 2 ways of deleting: either by id, in case only one document is deleted or by using a  match query, in which case multiple documents can be delete . Example of input to delete by id:    ```   {'index':'movies','id':100}   ```  Example of input to delete using a query:    ```   {     'index':'movies',     'query':     {       'bool':       {         'must':         [           {'query_string':'new movie'}         ]       }     }   }   ```  The match query has same syntax as in for searching. Responds with an object telling how many documents got deleted:     ```   {'_index':'products','updated':1}   ```   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete(delete_document_request, async_req=True)
        >>> result = thread.get()

        :param delete_document_request: (required)
        :type delete_document_request: DeleteDocumentRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: DeleteResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_with_http_info(delete_document_request, **kwargs)  # noqa: E501

    def delete_with_http_info(self, delete_document_request, **kwargs):  # noqa: E501
        """Delete a document in an index  # noqa: E501

        Delete one or several documents. The method has 2 ways of deleting: either by id, in case only one document is deleted or by using a  match query, in which case multiple documents can be delete . Example of input to delete by id:    ```   {'index':'movies','id':100}   ```  Example of input to delete using a query:    ```   {     'index':'movies',     'query':     {       'bool':       {         'must':         [           {'query_string':'new movie'}         ]       }     }   }   ```  The match query has same syntax as in for searching. Responds with an object telling how many documents got deleted:     ```   {'_index':'products','updated':1}   ```   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_with_http_info(delete_document_request, async_req=True)
        >>> result = thread.get()

        :param delete_document_request: (required)
        :type delete_document_request: DeleteDocumentRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(DeleteResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'delete_document_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )
        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'delete_document_request' is set
        if self.api_client.client_side_validation and ('delete_document_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['delete_document_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `delete_document_request` when calling `delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'delete_document_request' in local_var_params:
            body_params = local_var_params['delete_document_request']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        res = self.api_client.call_api(
            '/delete', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))
        return res
         

    def insert(self, insert_document_request, **kwargs):  # noqa: E501
        """Create a new document in an index  # noqa: E501

        Insert a document.  Expects an object like:     ```   {     'index':'movies',     'id':701,     'doc':     {       'title':'This is an old movie',       'plot':'A secret team goes to North Pole',       'year':1950,       'rating':9.5,       'lat':60.4,       'lon':51.99,       'advise':'PG-13',       'meta':'{\"keywords\":{\"travel\",\"ice\"},\"genre\":{\"adventure\"}}',       'language':[2,3]     }   }   ```   The document id can also be missing, in which case an autogenerated one will be used:             ```   {     'index':'movies',     'doc':     {       'title':'This is a new movie',       'plot':'A secret team goes to North Pole',       'year':2020,       'rating':9.5,       'lat':60.4,       'lon':51.99,       'advise':'PG-13',       'meta':'{\"keywords\":{\"travel\",\"ice\"},\"genre\":{\"adventure\"}}',       'language':[2,3]     }   }   ```   It responds with an object in format:      ```   {'_index':'products','_id':701,'created':true,'result':'created','status':201}   ```   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.insert(insert_document_request, async_req=True)
        >>> result = thread.get()

        :param insert_document_request: (required)
        :type insert_document_request: InsertDocumentRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SuccessResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.insert_with_http_info(insert_document_request, **kwargs)  # noqa: E501

    def insert_with_http_info(self, insert_document_request, **kwargs):  # noqa: E501
        """Create a new document in an index  # noqa: E501

        Insert a document.  Expects an object like:     ```   {     'index':'movies',     'id':701,     'doc':     {       'title':'This is an old movie',       'plot':'A secret team goes to North Pole',       'year':1950,       'rating':9.5,       'lat':60.4,       'lon':51.99,       'advise':'PG-13',       'meta':'{\"keywords\":{\"travel\",\"ice\"},\"genre\":{\"adventure\"}}',       'language':[2,3]     }   }   ```   The document id can also be missing, in which case an autogenerated one will be used:             ```   {     'index':'movies',     'doc':     {       'title':'This is a new movie',       'plot':'A secret team goes to North Pole',       'year':2020,       'rating':9.5,       'lat':60.4,       'lon':51.99,       'advise':'PG-13',       'meta':'{\"keywords\":{\"travel\",\"ice\"},\"genre\":{\"adventure\"}}',       'language':[2,3]     }   }   ```   It responds with an object in format:      ```   {'_index':'products','_id':701,'created':true,'result':'created','status':201}   ```   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.insert_with_http_info(insert_document_request, async_req=True)
        >>> result = thread.get()

        :param insert_document_request: (required)
        :type insert_document_request: InsertDocumentRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(SuccessResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'insert_document_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )
        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method insert" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'insert_document_request' is set
        if self.api_client.client_side_validation and ('insert_document_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['insert_document_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `insert_document_request` when calling `insert`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'insert_document_request' in local_var_params:
            body_params = local_var_params['insert_document_request']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        res = self.api_client.call_api(
            '/insert', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SuccessResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))
        return res
         

    def replace(self, insert_document_request, **kwargs):  # noqa: E501
        """Replace new document in an index  # noqa: E501

        Replace an existing document. Input has same format as `insert` operation. <br/> Responds with an object in format: <br/>    ```   {'_index':'products','_id':1,'created':false,'result':'updated','status':200}   ```   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.replace(insert_document_request, async_req=True)
        >>> result = thread.get()

        :param insert_document_request: (required)
        :type insert_document_request: InsertDocumentRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SuccessResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.replace_with_http_info(insert_document_request, **kwargs)  # noqa: E501

    def replace_with_http_info(self, insert_document_request, **kwargs):  # noqa: E501
        """Replace new document in an index  # noqa: E501

        Replace an existing document. Input has same format as `insert` operation. <br/> Responds with an object in format: <br/>    ```   {'_index':'products','_id':1,'created':false,'result':'updated','status':200}   ```   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.replace_with_http_info(insert_document_request, async_req=True)
        >>> result = thread.get()

        :param insert_document_request: (required)
        :type insert_document_request: InsertDocumentRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(SuccessResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'insert_document_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )
        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method replace" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'insert_document_request' is set
        if self.api_client.client_side_validation and ('insert_document_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['insert_document_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `insert_document_request` when calling `replace`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'insert_document_request' in local_var_params:
            body_params = local_var_params['insert_document_request']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        res = self.api_client.call_api(
            '/replace', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SuccessResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))
        return res
         

    def update(self, update_document_request, **kwargs):  # noqa: E501
        """Update a document in an index  # noqa: E501

        Update one or several documents. The update can be made by passing the id or by using a match query in case multiple documents can be updated.  For example update a document using document id:    ```   {'index':'movies','doc':{'rating':9.49},'id':100}   ```  And update by using a match query:    ```   {     'index':'movies',     'doc':{'rating':9.49},     'query':     {       'bool':       {         'must':         [           {'query_string':'new movie'}         ]       }     }   }   ```   The match query has same syntax as for searching. Responds with an object that tells how many documents where updated in format:     ```   {'_index':'products','updated':1}   ```   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update(update_document_request, async_req=True)
        >>> result = thread.get()

        :param update_document_request: (required)
        :type update_document_request: UpdateDocumentRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UpdateResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.update_with_http_info(update_document_request, **kwargs)  # noqa: E501

    def update_with_http_info(self, update_document_request, **kwargs):  # noqa: E501
        """Update a document in an index  # noqa: E501

        Update one or several documents. The update can be made by passing the id or by using a match query in case multiple documents can be updated.  For example update a document using document id:    ```   {'index':'movies','doc':{'rating':9.49},'id':100}   ```  And update by using a match query:    ```   {     'index':'movies',     'doc':{'rating':9.49},     'query':     {       'bool':       {         'must':         [           {'query_string':'new movie'}         ]       }     }   }   ```   The match query has same syntax as for searching. Responds with an object that tells how many documents where updated in format:     ```   {'_index':'products','updated':1}   ```   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_with_http_info(update_document_request, async_req=True)
        >>> result = thread.get()

        :param update_document_request: (required)
        :type update_document_request: UpdateDocumentRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(UpdateResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'update_document_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )
        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'update_document_request' is set
        if self.api_client.client_side_validation and ('update_document_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['update_document_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `update_document_request` when calling `update`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_document_request' in local_var_params:
            body_params = local_var_params['update_document_request']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        res = self.api_client.call_api(
            '/update', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UpdateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))
        return res
         

    def update_0(self, index, id, replace_document_request, **kwargs):  # noqa: E501
        """Partially replaces a document in an index  # noqa: E501

        Partially replaces a document with given id in an index Responds with an object of the following format:     ```   {'_index':'products','updated':1}   ```   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_0(index, id, replace_document_request, async_req=True)
        >>> result = thread.get()

        :param index: Name of the percolate index (required)
        :type index: str
        :param id: Id of the document to replace (required)
        :type id: float
        :param replace_document_request: (required)
        :type replace_document_request: ReplaceDocumentRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: UpdateResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.update_0_with_http_info(index, id, replace_document_request, **kwargs)  # noqa: E501

    def update_0_with_http_info(self, index, id, replace_document_request, **kwargs):  # noqa: E501
        """Partially replaces a document in an index  # noqa: E501

        Partially replaces a document with given id in an index Responds with an object of the following format:     ```   {'_index':'products','updated':1}   ```   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_0_with_http_info(index, id, replace_document_request, async_req=True)
        >>> result = thread.get()

        :param index: Name of the percolate index (required)
        :type index: str
        :param id: Id of the document to replace (required)
        :type id: float
        :param replace_document_request: (required)
        :type replace_document_request: ReplaceDocumentRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(UpdateResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'index', 
            'id', 
            'replace_document_request'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )
        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_0" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'index' is set
        if self.api_client.client_side_validation and ('index' not in local_var_params or  # noqa: E501
                                                        local_var_params['index'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `index` when calling `update_0`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in local_var_params or  # noqa: E501
                                                        local_var_params['id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `id` when calling `update_0`")  # noqa: E501
        # verify the required parameter 'replace_document_request' is set
        if self.api_client.client_side_validation and ('replace_document_request' not in local_var_params or  # noqa: E501
                                                        local_var_params['replace_document_request'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `replace_document_request` when calling `update_0`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'index' in local_var_params:
            path_params['index'] = local_var_params['index']  # noqa: E501
        if 'id' in local_var_params:
            path_params['id'] = local_var_params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'replace_document_request' in local_var_params:
            body_params = local_var_params['replace_document_request']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        res = self.api_client.call_api(
            '/{index}/_update/{id}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UpdateResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))
        return res
         



# coding: utf-8
# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
#
# All rights reserved

from __future__ import absolute_import
from pprint import pprint
import unittest
import json
import manticoresearch
from manticoresearch.api.index_api import IndexApi  # noqa: E501
from manticoresearch.model import *
from manticoresearch.rest import ApiException
from parametrized_test_case import ParametrizedTestCase
from urllib.parse import quote
import sys

class TestManualApi(ParametrizedTestCase):

    def setUp(self):
        self.client = manticoresearch.ApiClient(self.settings['configuration'])
        
    def tearDown(self):
        pass
        
    def test_manual(self):
        client = self.client
        indexApi = manticoresearch.IndexApi(client)
        utilsApi = manticoresearch.UtilsApi(client)
        searchApi = manticoresearch.SearchApi(client)
        
        utilsApi.sql('DROP TABLE IF EXISTS movies')
        res = utilsApi.sql("CREATE TABLE IF NOT EXISTS movies (title text, plot text, _year integer, rating float, code multi, type_vector float_vector knn_type='hnsw' knn_dims='3' hnsw_similarity='l2' )")
        
        docs = [
            {"insert": {"index" : "movies", "id" : 1, "doc" : {"title" : "Star Trek 2: Nemesis", "plot": "The Enterprise is diverted to the Romulan homeworld Romulus, supposedly because they want to negotiate a peace treaty. Captain Picard and his crew discover a serious threat to the Federation once Praetor Shinzon plans to attack Earth.", "_year": 2002, "rating": 6.4, "code": [1,2,3], "type_vector": [0.2, 1.4, -2.3]}}},
            {"insert": {"index" : "movies", "id" : 2, "doc" : {"title" : "Star Trek 1: Nemesis", "plot": "The Enterprise is diverted to the Romulan homeworld Romulus, supposedly because they want to negotiate a peace treaty. Captain Picard and his crew discover a serious threat to the Federation once Praetor Shinzon plans to attack Earth.", "_year": 2001, "rating": 6.5, "code": [1,12,3], "type_vector": [0.8, 0.4, 1.3]}}},
            {"insert": {"index" : "movies", "id" : 3, "doc" : {"title" : "Star Trek 3: Nemesis", "plot": "The Enterprise is diverted to the Romulan homeworld Romulus, supposedly because they want to negotiate a peace treaty. Captain Picard and his crew discover a serious threat to the Federation once Praetor Shinzon plans to attack Earth.", "_year": 2003, "rating": 6.6, "code": [11,2,3], "type_vector": [1.5, -1.0, 1.6]}}},
            {"insert": {"index" : "movies", "id" : 4, "doc" : {"title" : "Star Trek 4: Nemesis", "plot": "The Enterprise is diverted to the Romulan homeworld Romulus, supposedly because they want to negotiate a peace treaty. Captain Picard and his crew discover a serious threat to the Federation once Praetor Shinzon plans to attack Earth.", "_year": 2003, "rating": 6.5, "code": [1,2,4], "type_vector": [0.4, 2.4, 0.9]}}},
        ]
        indexApi.bulk("\n".join(map(json.dumps,docs)))
        
        
        search_request = SearchRequest(
            index="movies",
            query={"match_all": {}}
        ) 
        
        res = searchApi.search(search_request)
        
        search_request.index = 'movies'
        search_request.limit = 10
        search_request.track_scores = True
        search_request.options = {'cutoff': 5}
        search_request.options['ranker'] = 'bm25'
        search_request.source = 'title'

        res = searchApi.search(search_request)
        
        search_request.source = SourceByRules()
        search_request.source.includes = ['title', '_year']
        search_request.source.excludes = ['code']

        res = searchApi.search(search_request)

        search_request.sort = ['_year']
        sort2 = manticoresearch.model.SortOrder('rating', 'asc')
        sort3 = manticoresearch.model.SortMVA('code', 'desc', 'max')
        search_request.sort += [sort2,sort3]
        
        res = searchApi.search(search_request)

        search_request.expressions = {'expr': 'min(_year,2900)'}
        search_request.expressions['expr2'] = 'max(_year,2100)'
        search_request.source.includes += ['expr2', 'expr']
        
        res = searchApi.search(search_request)
        		
        aggTerms1 = AggregationTerms('_year', 10)
        agg1 = Aggregation(aggTerms1)
        agg2 = Aggregation(AggregationTerms('rating'), ['rating'])
        search_request.aggs = {'agg1': agg1}
        search_request.aggs['agg2'] = agg2
        

        highlight = manticoresearch.model.Highlight()
        highlight.fieldnames = ['title']
        highlight.post_tags = '</post_tag>'
        highlight.encoder = 'default'
        highlight.snippet_boundary = 'sentence'
        search_request.highlight = highlight 
        
        res = searchApi.search(search_request)

        highlightField = HighlightField('title')
        highlightField2 = HighlightField('plot', 5, 10)
        highlight.fields = [highlightField, highlightField2]
        search_request.highlight = highlight
        
        res = searchApi.search(search_request)

        highlight.highlight_query = {"match" : {"*": "Star"} };
        search_request.highlight = highlight

        res = searchApi.search(search_request)

        search_request.fulltext_filter = QueryFilter('Star Trek 2')

        res = searchApi.search(search_request)        

        search_request.fulltext_filter = MatchFilter('Nemesis', 'title')

        res = searchApi.search(search_request)

        search_request.fulltext_filter = MatchPhraseFilter('Star Trek 2', 'title')

        res = searchApi.search(search_request)

        search_request.fulltext_filter = MatchOpFilter('Enterprise test', 'title,plot', 'or') 
        
        res = searchApi.search(search_request)

        search_request.attr_filter = EqualsFilter('_year', 2001)
        
        res = searchApi.search(search_request)

        inFilter = InFilter('_year', [2001, 2002])
        inFilter.values += [10,11]
        search_request.attr_filter = inFilter
        
        res = searchApi.search(search_request)

        rangeFilter = RangeFilter('_year', lte = 2002)
        rangeFilter.gte = 1000
        search_request.attr_filter = rangeFilter

        res = searchApi.search(search_request)
        
        rangeFilter = RangeFilter('rating')
        rangeFilter.gt = 2000.5
        rangeFilter.lt = 2002
        search_request.attr_filter = rangeFilter

        res = searchApi.search(search_request)

        geoFilter = GeoDistanceFilter(location_anchor={'lat':10,'lon':20.5}, location_source='_year,rating')
        geoFilter.location_source='_year,rating'
        geoFilter.distance_type='adaptive'
        geoFilter.distance='100 km'
        search_request.attr_filter = geoFilter
        
        res = searchApi.search(search_request)

        boolFilter = BoolFilter()
        boolFilter.must = [ EqualsFilter('_year', 2001) ]
        boolFilter.must += [ RangeFilter('rating', lte = 20) ]
        search_request.attr_filter = boolFilter
        
        res = searchApi.search(search_request)

        boolFilter.must_not = [ EqualsFilter('_year', 2001) ]
        
        res = searchApi.search(search_request)
        
        fulltext_filter = MatchFilter('Star', 'title')
        nestedBoolFilter = BoolFilter()
        nestedBoolFilter.should = [EqualsFilter('rating', 6.5), fulltext_filter]
        boolFilter.must = [nestedBoolFilter]
        
        res = searchApi.search(search_request)

        search_request.attr_filter = boolFilter
    
        res = searchApi.search(search_request)
        pprint(res)

        search_request = SearchRequest(
            index="movies",
        )
        search_request.knn = KnnQueryByVector(
            field="type_vector",
            query_vector=[1.5, -1.0, 1.6],
            k=5,
        )
        res = searchApi.search(search_request)

        search_request.knn = KnnQueryByDocId(
            field="type_vector",
            doc_id=2,
            k=5,
        )
        res = searchApi.search(search_request)

        boolFilter = BoolFilter()
        boolFilter.must = [ EqualsFilter('id', 3) ]
        search_request.knn = KnnQueryByVector(
            field="type_vector",
            query_vector=[1.5, -1.0, 1.6],
            k=5,
            filter=boolFilter,
        )
        res = searchApi.search(search_request)
        
        search_request.knn = KnnQueryByDocId(
            field="type_vector",
            doc_id=2,
            k=5,
            filter=boolFilter,
        )
        res = searchApi.search(search_request)
                        
        print("\nSearch tests finished\n")
        
        utilsApi.sql('SHOW THREADS')
        utilsApi.sql('DROP TABLE IF EXISTS products')
        # example create_example request
        res = utilsApi.sql('CREATE TABLE IF NOT EXISTS products (title text, price float, sizes multi, meta json, coeff float, tags1 multi, tags2 multi)')
        pprint(res)
        # example not raw_response request
        res = utilsApi.sql('SELECT * FROM products', raw_response=False)
        pprint(res)
        res = utilsApi.sql('SELECT * FROM products', raw_response=True)
        pprint(res)
        res = utilsApi.sql('TRUNCATE TABLE products')
        # example create_example response
        #
        #
        #
        print(res)
        self.assertEqual(res[0]['error'],'')
        indexApi = api = manticoresearch.IndexApi(client)
        # example insert request
        indexApi.insert({"index" : "products", "id" : 1, "doc" : {"title" : "Crossbody Bag with Tassel", "price" : 19.85}})
        indexApi.insert({"index" : "products", "id" : 2, "doc" : {"title" : "Crossbody Bag with Tassel"}})
        indexApi.insert({"index" : "products", "id" : 0, "doc" : {"title" : "Yellow bag"}})
        # example autoid request
        indexApi.insert({"index" : "products", "id" : 0, "doc" : {"title" : "Yellow bag"}})
        # example bulk_insert request
        indexApi = api = manticoresearch.IndexApi(client)
        docs = [ \
            {"insert": {"index" : "products", "id" : 3, "doc" : {"title" : "Crossbody Bag with Tassel", "price" : 19.85}}}, \
            {"insert": {"index" : "products", "id" : 4, "doc" : {"title" : "microfiber sheet set", "price" : 19.99}}}, \
            {"insert": {"index" : "products", "id" : 5, "doc" : {"title" : "CPet Hair Remover Glove", "price" : 7.99}}}
        ]
        print('\n'.join(map(json.dumps,docs)))
        api_resp = indexApi.bulk('\n'.join(map(json.dumps,docs)))
        # example MVA_insert request
        indexApi = api = manticoresearch.IndexApi(client)
        indexApi.insert({"index" : "products", "id" : 0, "doc" : {"title" : "Yellow bag","sizes":[40,41,42,43]}})
        # example JSON_insert request
        indexApi = api = manticoresearch.IndexApi(client)
        indexApi.insert({"index" : "products", "id" : 0, "doc" : {"title" : "Yellow bag","meta":'{"size": 41, "color": "red"}'}})
        # example replace request
        api_resp = indexApi.replace({"index" : "products", "id" : 1, "doc" : {"title" : "document one","price":10}})

        # example replace response
        # {'created': False,
        # 'found': None,
        # 'id': 1,
        # 'index': 'products',
        # 'result': 'updated'}
        
        # example bulk_replace request
        docs = [ \
            {"replace": {"index" : "products", "id" : 1, "doc" : {"title" : "document one"}}}, \
            {"replace": {"index" : "products", "id" : 2, "doc" : {"title" : "document two"}}} ]
        api_resp = indexApi.bulk('\n'.join(map(json.dumps,docs)))
        
        # example bulk_replace response
        #{'error': None,
        #'items': [{u'replace': {u'_id': 1,
        #                 u'_index': u'products',
        #                 u'created': False,
        #                 u'result': u'updated',
        #                 u'status': 200}},
        #   {u'replace': {u'_id': 2,
        #                u'_index': u'products',
        #                 u'created': False,
        #                 u'result': u'updated',
        #                 u'status': 200}}]}
        
        # example update request
        api_resp = indexApi.update({"index" : "products", "id" : 1, "doc" : {"price":10}})
        pprint(api_resp)
        # example update respone
        # {'id': 1, 'index': 'products', 'result': 'updated', 'updated': None}
        
        # example update multiple attributes request
        api_resp = indexApi.update({"index" : "products", "id" : 1, "doc" : {
            "price": 100000000000,
            "coeff": 3465.23,
            "tags1": [3,6,4],
            "tags2": []}})
        pprint(api_resp)
        # example update multiple attributes respone
        # {'id': 1, 'index': 'products', 'result': 'updated', 'updated': None}
        
        
        
        # example partial JSON update request
        api_resp = indexApi.insert({"index" : "products", "id" : 100, "doc" : {"title" : "title", "meta" : {"tags":[1,2,3]}}})
        pprint(api_resp)
        api_resp = indexApi.update({"index" : "products", "id" : 100, "doc" : {
            "meta.tags[0]": 100}})
        pprint(api_resp)
        # example partial JSON update respone
        #{'created': True,
        #'found': None,
        #'id': 100,
        #'index': 'products',
        #'result': 'created'}
        #{'id': 100, 'index': 'products', 'result': 'updated', 'updated': None}      

        # example MVA empty update request
        api_resp = indexApi.update({"index" : "products", "id" : 1, "doc" : {"tags1": []}})
        pprint(api_resp)
        
        # example bulk by query request
        docs = [ \
            { "update" : { "index" : "products", "doc": { "coeff" : 1000 }, "query": { "range": { "price": { "gte": 1000 } } } } }, \
            { "update" : { "index" : "products", "doc": { "coeff" : 0 }, "query": { "range": { "price": { "lt": 1000 } } } } } ]
        api_resp = indexApi.bulk('\n'.join(map(json.dumps,docs)))
        pprint(api_resp)
        
        # example delete 2 request
        api_resp = indexApi.delete({"index" : "products", "query": { "match": { "*": "document" }}})
        pprint(api_resp)        
        
        # example delete 3 request
        api_resp = indexApi.delete({"index" : "products", "id" : 1})
        pprint(api_resp)      

        # example truncate request
        res = utilsApi.sql('TRUNCATE TABLE products')
        pprint(res)
        
        #
        
        res = utilsApi.sql('SHOW TABLES LIKE \'pro%\'')
        pprint(res)
        
        #
        res = utilsApi.sql('drop table if exists forum')
        utilsApi.sql('create table forum(title text, content text, author_id int, forum_id int, post_date timestamp) min_infix_len=\'3\'')
        # example filtered query request
        res = searchApi.search({"index":"forum","query":{"match_all":{},"bool":{"must":[{"equals":{"author_id":123}},{"in":{"forum_id":[1,3,7]}}]}},"sort":[{"post_date":"desc"}]})
        pprint(res)
        
        #
        print('HERE')
        indexApi.insert({"index" : "forum", "id" : 0, "doc" : {"title" : "i me"}})
        indexApi.insert({"index" : "forum", "id" : 0, "doc" : {"title" : "wayne","content":"hey"}})
        res = searchApi.search({"index":"forum","query":{"query_string":"i me"},"_source":{"excludes":["*"]},"limit":1,"profile":True})
        pprint(res)
        res = searchApi.search({"index":"forum","query":{"query_string":"@title way* @content hey"},"_source":{"excludes":["*"]},"limit":1,"profile":True})
        pprint(res)
        
        #
        utilsApi.sql('DROP TABLE products')
        res = utilsApi.sql('CREATE TABLE IF NOT EXISTS products (title text,product_codes multi)')
        
        res = indexApi.insert({"index":"products","id":1,"doc":{"title":"first","product_codes":[4,2,1,3]}})
        pprint(res)
        res = indexApi.insert({"index":"products","id":2,"doc":{"title":"second","product_codes":[5,6,8,7]}})
        res = searchApi.search({"index":"products","query":{"match_all":{}}})
        pprint(res)
        res = searchApi.search({"index":"products","query":{"match_all":{}}, "options":{"max_matches":1}})
        pprint(res)
        utilsApi.sql('DROP TABLE products')
        
        #
        
        res =  utilsApi.sql('SHOW AGENT STATUS')
        pprint(res)
        
        # example create percolate request
        
        #utilsApi.sql('create table products(title text, color string) type=\'pq\'')
        #res = indexApi.insert({"index" : "products", "doc" : {"query" : "@title bag" }})
        #pprint(res)
        #res = indexApi.insert({"index" : "products",  "doc" : {"query" : "@title shoes", "filters": "color='red'" }})
        #pprint(res)
        #res = indexApi.insert({"index" : "products",  "doc" : {"query" : "@title shoes","filters": "color in ('blue', 'green')" }})
        #pprint(res)
        
        #
        
        #res = searchApi.percolate('products',{"query":{"percolate":{"document":{"title":"What a nice bag"}}}})
        #pprint(res)
        #res = searchApi.percolate('products',{"query":{"percolate":{"documents":[{"title":"nice pair of shoes","color":"blue"},{"title":"beautiful bag"}]}}})
        #pprint(res)        
        #res = searchApi.search({"index":"products","query":{"match_all":{}}})
        #pprint(res)        
        #utilsApi.sql('DROP TABLE products')
        
        
        #res =  searchApi.search({"index":"books","query":{"match":{"*":"try"}},"highlight":{}})
        #pprint(res)
        
        pprint("Tests finished")
        
if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
# 
# All rights reserved
#



import pprint
import re  # noqa: F401

import six

from manticoresearch.configuration import Configuration

class RangeFilter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'field': 'str',
        'lte': 'float, none_type',
        'gte': 'float, none_type',
        'lt': 'float, none_type',
        'gt': 'float, none_type'
    }

    attribute_map = {
        'field': 'field',
        'lte': 'lte',
        'gte': 'gte',
        'lt': 'lt',
        'gt': 'gt'
    }

    def __init__(self, field=None, lte=None, gte=None, lt=None, gt=None, local_vars_configuration=None):  # noqa: E501
        """RangeFilter - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._field = None
        self._lte = None
        self._gte = None
        self._lt = None
        self._gt = None
        self.discriminator = None

        self.field = field
        self.lte = lte
        self.gte = gte
        self.lt = lt
        self.gt = gt

    @property
    def field(self):
        """Gets the field of this RangeFilter.  # noqa: E501


        :return: The field of this RangeFilter.  # noqa: E501
        :rtype: str
        """
        return self._field
    @field.setter
    def field(self, field):
        """Sets the field of this RangeFilter.


        :param field: The field of this RangeFilter.  # noqa: E501
        :type field: str
        """
        if self.local_vars_configuration.client_side_validation and field is None:  # noqa: E501
            raise ValueError("Invalid value for `field`, must not be `None`")  # noqa: E501

        self._field = field
        

    @property
    def lte(self):
        """Gets the lte of this RangeFilter.  # noqa: E501


        :return: The lte of this RangeFilter.  # noqa: E501
        :rtype: float, none_type
        """
        return self._lte
    @lte.setter
    def lte(self, lte):
        """Sets the lte of this RangeFilter.


        :param lte: The lte of this RangeFilter.  # noqa: E501
        :type lte: float, none_type
        """

        self._lte = lte
        

    @property
    def gte(self):
        """Gets the gte of this RangeFilter.  # noqa: E501


        :return: The gte of this RangeFilter.  # noqa: E501
        :rtype: float, none_type
        """
        return self._gte
    @gte.setter
    def gte(self, gte):
        """Sets the gte of this RangeFilter.


        :param gte: The gte of this RangeFilter.  # noqa: E501
        :type gte: float, none_type
        """

        self._gte = gte
        

    @property
    def lt(self):
        """Gets the lt of this RangeFilter.  # noqa: E501


        :return: The lt of this RangeFilter.  # noqa: E501
        :rtype: float, none_type
        """
        return self._lt
    @lt.setter
    def lt(self, lt):
        """Sets the lt of this RangeFilter.


        :param lt: The lt of this RangeFilter.  # noqa: E501
        :type lt: float, none_type
        """

        self._lt = lt
        

    @property
    def gt(self):
        """Gets the gt of this RangeFilter.  # noqa: E501


        :return: The gt of this RangeFilter.  # noqa: E501
        :rtype: float, none_type
        """
        return self._gt
    @gt.setter
    def gt(self, gt):
        """Sets the gt of this RangeFilter.


        :param gt: The gt of this RangeFilter.  # noqa: E501
        :type gt: float, none_type
        """

        self._gt = gt
        


    def to_dict(self):
        """Returns the model properties as a dict"""
        result = { 'range': {self._field: { 'gte': self._gte, 'lte': self._lte, 'gt': self._gt, 'lt': self._lt } } }
        result['range'][self._field] = {k:v for k,v in result['range'][self._field].items() if v is not None}




        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RangeFilter):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, RangeFilter):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
# 
# All rights reserved
#



import pprint
import re  # noqa: F401

import six

from manticoresearch.configuration import Configuration

class GeoDistanceFilter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'location_anchor': 'GeoDistanceFilterLocationAnchor',
        'location_source': 'str',
        'distance_type': 'str',
        'distance': 'str'
    }

    attribute_map = {
        'location_anchor': 'location_anchor',
        'location_source': 'location_source',
        'distance_type': 'distance_type',
        'distance': 'distance'
    }

    def __init__(self, location_anchor=None, location_source=None, distance_type=None, distance=None, local_vars_configuration=None):  # noqa: E501
        """GeoDistanceFilter - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._location_anchor = None
        self._location_source = None
        self._distance_type = None
        self._distance = None
        self.discriminator = None

        if location_anchor is not None:
            self.location_anchor = location_anchor
        if location_source is not None:
            self.location_source = location_source
        if distance_type is not None:
            self.distance_type = distance_type
        if distance is not None:
            self.distance = distance

    @property
    def location_anchor(self):
        """Gets the location_anchor of this GeoDistanceFilter.  # noqa: E501


        :return: The location_anchor of this GeoDistanceFilter.  # noqa: E501
        :rtype: GeoDistanceFilterLocationAnchor
        """
        return self._location_anchor
    @location_anchor.setter
    def location_anchor(self, location_anchor):
        """Sets the location_anchor of this GeoDistanceFilter.


        :param location_anchor: The location_anchor of this GeoDistanceFilter.  # noqa: E501
        :type location_anchor: GeoDistanceFilterLocationAnchor
        """

        self._location_anchor = location_anchor
        

    @property
    def location_source(self):
        """Gets the location_source of this GeoDistanceFilter.  # noqa: E501

        Attribute containing latitude and longitude data  # noqa: E501

        :return: The location_source of this GeoDistanceFilter.  # noqa: E501
        :rtype: str
        """
        return self._location_source
    @location_source.setter
    def location_source(self, location_source):
        """Sets the location_source of this GeoDistanceFilter.

        Attribute containing latitude and longitude data  # noqa: E501

        :param location_source: The location_source of this GeoDistanceFilter.  # noqa: E501
        :type location_source: str
        """

        self._location_source = location_source
        

    @property
    def distance_type(self):
        """Gets the distance_type of this GeoDistanceFilter.  # noqa: E501


        :return: The distance_type of this GeoDistanceFilter.  # noqa: E501
        :rtype: str
        """
        return self._distance_type
    @distance_type.setter
    def distance_type(self, distance_type):
        """Sets the distance_type of this GeoDistanceFilter.


        :param distance_type: The distance_type of this GeoDistanceFilter.  # noqa: E501
        :type distance_type: str
        """
        allowed_values = ["adaptive", "haversine"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and distance_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `distance_type` ({0}), must be one of {1}"  # noqa: E501
                .format(distance_type, allowed_values)
            )

        self._distance_type = distance_type
        

    @property
    def distance(self):
        """Gets the distance of this GeoDistanceFilter.  # noqa: E501


        :return: The distance of this GeoDistanceFilter.  # noqa: E501
        :rtype: str
        """
        return self._distance
    @distance.setter
    def distance(self, distance):
        """Sets the distance of this GeoDistanceFilter.


        :param distance: The distance of this GeoDistanceFilter.  # noqa: E501
        :type distance: str
        """

        self._distance = distance
        


    def to_dict(self):
        """Returns the model properties as a dict"""

        result = {}		
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        result = { 'geo_distance': result }


        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GeoDistanceFilter):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GeoDistanceFilter):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from manticoresearch.api.index_api import IndexApi
from manticoresearch.api.search_api import SearchApi
from manticoresearch.api.utils_api import UtilsApi



# coding: utf-8

# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
# 
# All rights reserved
#



import pprint
import re  # noqa: F401

import six

from manticoresearch.configuration import Configuration

class SearchResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'took': 'int',
        'timed_out': 'bool',
        'aggregations': '{str: (bool, date, datetime, dict, float, int, list, str, none_type)}',
        'hits': 'SearchResponseHits',
        'profile': '{str: (bool, date, datetime, dict, float, int, list, str, none_type)}',
        'warning': '{str: (bool, date, datetime, dict, float, int, list, str, none_type)}'
    }

    attribute_map = {
        'took': 'took',
        'timed_out': 'timed_out',
        'aggregations': 'aggregations',
        'hits': 'hits',
        'profile': 'profile',
        'warning': 'warning'
    }

    def __init__(self, took=None, timed_out=None, aggregations=None, hits=None, profile=None, warning=None, local_vars_configuration=None):  # noqa: E501
        """SearchResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._took = None
        self._timed_out = None
        self._aggregations = None
        self._hits = None
        self._profile = None
        self._warning = None
        self.discriminator = None

        if took is not None:
            self.took = took
        if timed_out is not None:
            self.timed_out = timed_out
        if aggregations is not None:
            self.aggregations = aggregations
        if hits is not None:
            self.hits = hits
        if profile is not None:
            self.profile = profile
        if warning is not None:
            self.warning = warning

    @property
    def took(self):
        """Gets the took of this SearchResponse.  # noqa: E501


        :return: The took of this SearchResponse.  # noqa: E501
        :rtype: int
        """
        return self._took
    @took.setter
    def took(self, took):
        """Sets the took of this SearchResponse.


        :param took: The took of this SearchResponse.  # noqa: E501
        :type took: int
        """

        self._took = took
        

    @property
    def timed_out(self):
        """Gets the timed_out of this SearchResponse.  # noqa: E501


        :return: The timed_out of this SearchResponse.  # noqa: E501
        :rtype: bool
        """
        return self._timed_out
    @timed_out.setter
    def timed_out(self, timed_out):
        """Sets the timed_out of this SearchResponse.


        :param timed_out: The timed_out of this SearchResponse.  # noqa: E501
        :type timed_out: bool
        """

        self._timed_out = timed_out
        

    @property
    def aggregations(self):
        """Gets the aggregations of this SearchResponse.  # noqa: E501


        :return: The aggregations of this SearchResponse.  # noqa: E501
        :rtype: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """
        return self._aggregations
    @aggregations.setter
    def aggregations(self, aggregations):
        """Sets the aggregations of this SearchResponse.


        :param aggregations: The aggregations of this SearchResponse.  # noqa: E501
        :type aggregations: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """

        self._aggregations = aggregations
        

    @property
    def hits(self):
        """Gets the hits of this SearchResponse.  # noqa: E501


        :return: The hits of this SearchResponse.  # noqa: E501
        :rtype: SearchResponseHits
        """
        return self._hits
    @hits.setter
    def hits(self, hits):
        """Sets the hits of this SearchResponse.


        :param hits: The hits of this SearchResponse.  # noqa: E501
        :type hits: SearchResponseHits
        """

        self._hits = hits
        

    @property
    def profile(self):
        """Gets the profile of this SearchResponse.  # noqa: E501


        :return: The profile of this SearchResponse.  # noqa: E501
        :rtype: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """
        return self._profile
    @profile.setter
    def profile(self, profile):
        """Sets the profile of this SearchResponse.


        :param profile: The profile of this SearchResponse.  # noqa: E501
        :type profile: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """

        self._profile = profile
        

    @property
    def warning(self):
        """Gets the warning of this SearchResponse.  # noqa: E501


        :return: The warning of this SearchResponse.  # noqa: E501
        :rtype: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """
        return self._warning
    @warning.setter
    def warning(self, warning):
        """Sets the warning of this SearchResponse.


        :param warning: The warning of this SearchResponse.  # noqa: E501
        :type warning: {str: (bool, date, datetime, dict, float, int, list, str, none_type)}
        """

        self._warning = warning
        


    def to_dict(self):
        """Returns the model properties as a dict"""

        result = {}		
        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value



        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SearchResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# Manticore Search Client
# Copyright (c) 2020-2021, Manticore Software LTD (https://manticoresearch.com)
# 
# All rights reserved
#



from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six
from six.moves.urllib.parse import quote

from manticoresearch.api_client import ApiClient
from manticoresearch.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class UtilsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def sql(self, body, **kwargs):  # noqa: E501
        """Perform SQL requests  # noqa: E501

        Run a query in SQL format. Expects a query string passed through `body` parameter and optional `raw_response` parameter that defines a format of response. `raw_response` can be set to `False` for Select queries only, e.g., `SELECT * FROM myindex` The query string must stay as it is, no URL encoding is needed. The response object depends on the query executed. In select mode the response has same format as `/search` operation.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.sql(body, async_req=True)
        >>> result = thread.get()

        :param body: A query parameter string.  (required)
        :type body: str
        :param raw_response: Optional parameter, defines a format of response. Can be set to `False` for Select only queries and set to `True` or omitted for any type of queries: 
        :type raw_response: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SqlResponse
        """
        kwargs['_return_http_data_only'] = True
        return self.sql_with_http_info(body, **kwargs)  # noqa: E501

    def sql_with_http_info(self, body, **kwargs):  # noqa: E501
        """Perform SQL requests  # noqa: E501

        Run a query in SQL format. Expects a query string passed through `body` parameter and optional `raw_response` parameter that defines a format of response. `raw_response` can be set to `False` for Select queries only, e.g., `SELECT * FROM myindex` The query string must stay as it is, no URL encoding is needed. The response object depends on the query executed. In select mode the response has same format as `/search` operation.   # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.sql_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param body: A query parameter string.  (required)
        :type body: str
        :param raw_response: Optional parameter, defines a format of response. Can be set to `False` for Select only queries and set to `True` or omitted for any type of queries: 
        :type raw_response: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(SqlResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = [
            'body', 
            'raw_response'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth'
            ]
        )
        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method sql" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `sql`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'raw_response' in local_var_params and local_var_params['raw_response'] is not None:  # noqa: E501
            query_params.append(('raw_response', local_var_params['raw_response']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
          if  'raw_response' in local_var_params and not local_var_params['raw_response']:
              body_params = 'query=' 
          elif not 'raw_response' in local_var_params or local_var_params['raw_response']:
              body_params = 'mode=raw&query='
          body_params += quote( str( local_var_params['body'] ) )

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['text/plain'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        res = self.api_client.call_api(
            '/sql', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SqlResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get('_request_auth'))
        return [ res ] if 'raw_response' in local_var_params and not local_var_params['raw_response'] else res
         
